@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Parse the UCI Bach choral harmony data set
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Moo;
 use strictures 2;
@@ -246,7 +246,7 @@ Music::BachChoralHarmony - Parse the UCI Bach choral harmony data set
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
@@ -334,8 +334,8 @@ Create a new C<Music::BachChoralHarmony> object.
 
   $songs = $bach->parse();
 
-Parse the B<data_file> and B<key_title> files into a hash reference
-B<data> of each song keyed by the song id.  Each song includes a BWV
+Parse the B<data_file> and B<key_title> files into a B<data> hash
+reference of each song keyed by the song id.  Each song includes a BWV
 identifier, title, key and list of events.  The event list is made of
 hash references with keys for the notes bit string, bass note, the
 accent value and the resonating chord.
@@ -391,7 +391,7 @@ L<https://github.com/ology/Bach-Chorales/blob/master/bin/key.py>
 
 =head1 THANK YOU
 
-Dan Book (DBOOK) for the ShareDir clues.
+Dan Book (L<DBOOK|https://metacpan.org/author/DBOOK>) for the ShareDir clues.
 
 =head1 AUTHOR
 
@@ -399,7 +399,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2018 by Gene Boggs.
+This software is copyright (c) 2019 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
